<?php

namespace Focus\Focus\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Focus\Focus\Interfaces\CustomerRepositoryInterface;

class CustomerPublicController extends BaseController
{
    // use CustomerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Focus\Customer\Interfaces\CustomerRepositoryInterface $customer
     *
     * @return type
     */
    public function __construct(CustomerRepositoryInterface $customer)
    {
        $this->repository = $customer;
        parent::__construct();
    }

    /**
     * Show customer's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $customers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$focus::$customer.names'))
            ->view('$focus::public.customer.index')
            ->data(compact('$customers'))
            ->output();
    }

    /**
     * Show customer's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $customers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$focus::$customer.names'))
            ->view('$focus::public.customer.index')
            ->data(compact('$customers'))
            ->output();
    }

    /**
     * Show customer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $customer = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$customer->name . trans('$focus::$customer.name'))
            ->view('$focus::public.customer.show')
            ->data(compact('$customer'))
            ->output();
    }

}
