<?php

namespace Focus\Focus\Providers;

use Illuminate\Support\ServiceProvider;

class FocusServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'focus');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'focus');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.focus', function ($app) {
            return $this->app->make('Focus\Focus\Focus');
        });

        // Bind Customer to repository
        $this->app->bind(
            'Focus\Focus\Interfaces\CustomerRepositoryInterface',
            \Focus\Focus\Repositories\Eloquent\CustomerRepository::class
        );
        // Bind Product to repository
        $this->app->bind(
            'Focus\Focus\Interfaces\ProductRepositoryInterface',
            \Focus\Focus\Repositories\Eloquent\ProductRepository::class
        );

        $this->app->register(\Focus\Focus\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Focus\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.focus'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/focus.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/focus')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/focus')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
